# Next


Plugin Stuff:

- [ ] Workspace
- [ ] Plugin SDK
- [ ] Build a nice plugin
- [ ] Supervisor
- [ ] Conceptual: DAG, Caching & Context-Storing
- [ ] Python integration


Easy and Important:

- [ ] Universal Comments
- [ ] What makes an App (I guess a distribution of plugins)


Very Strong Plugin Calling

- [ ] Supervisor & gRPC Tool => local-grpc
- [ ] Datamodel with library and Adapters (only 2 for now: FFI, local-grpc)
- [ ] Context in Consumers and Producers? -> Concept first!


Tools 

- [x] Python Tools
- [x] Rust Tools
- [x] One tool in rust, One tool in python - working together
- [x] Import Tools
- [ ] Bash tools
- [ ] Loaded python tools
- [ ] Loaded rust tools
- [ ] Library of Tools
- [ ] Get my conceptual understanding right: .page vs something which requires the complete block
- [ ] A concept of tool libraries to activate / load them
- [ ] Tool via CLI (& gRPC?)

Today:

- [ ] Loading Libraries
- [ ] Universal comments (part of the text element)
- [ ] Plugin components: Tools (full + meta-line), Actions, Exporters -> Concept doc

Catching up with technical dept

- [x] Integratioin Test Generation + Tools to write them
- [ ] Python integration tests
- [ ] Generate Integration Tests with Selectors
- [ ] Great Documenation Website for Documentation driven development
- [ ] Documentation on how to run the different types of tests, incl. 
    - fuzzying, large file tests, syntax-tests and so on
    - performance testing & regression detection


Next Required steps:

- [ ] Custom events
- [ ] File-Metadata (header or stdlib?)
- [ ] High level tests

Misc:

- [ ] A StackFrameCollector as utility in Rust, which supports Selectors
- [ ] Draft a Vision and Roadmap for v0.1 


Milestone: Actions & Standard Library

- [ ] Custom Events (part of the event log, used to define variables)
- [ ] Actions (which require selectors to register them) 
- [ ] Libraries, which provide actions using gRPC, etc.
- [ ] A standard-library
- [ ] LSP should support features

Milestone: All to all

- [ ] create a pretty command (wasot2wasot)
- [ ] Write a bunch of tests against the facade
- [ ] All to All command as demo. Pandoc style

Milestone: Python Tooling

- [x] Good SDK, which is fun to use
- [ ] Collect a Stack

Milestone: LSP & Editor Integration

- [ ] Build LSP for formatting
- [ ] Navigation via Selectors (like vim+css)
- [ ] Treesitter using Rust

Features

- [ ] Project format
- [ ] Enable fast random access in events file? (A book allows this by numbered chapters & numbered sub-chapters)
- [ ] Attachments

## Tools

- Zettelkasten
- Flashcards & Rolling summary
- Bulletpoint Writing
- Jupyter notebook
- PlantUML in text
- Epub & HTML to wasot
- Manim
- Enable: Consume to Produce
- Artifact creation
- Book writing
- Building Websites - markdown is too restricted
- 2D Vim
- Building a map of thoughts as garden
- Demo Project to Tutorial (full projects -> diffs -> wasot -> video-script)
- My social network, never forget

Crazy ideas
- An Operating System / Desktop-Manager?
- Specialized hardware

## Missing Things to build the Tools

- Selectors & Subscribers (Actions / Facade)
- Attachments
- Nice Python Lib
- Good LSP with Tool Integration
